<?php
/*
Plugin Name: Lightbox 2 Plugin
Plugin URI: http://www.m3nt0r.de/blog/lightbox-wordpress-plugin/
Feed URI:
Description: Автоматически конвертирует все ссылки на картинки в записях, выдержках и комментариях на lightboxed ссылки. (смотри меню в Настройках). -- Использует Lightbox v2.03.3 и сжатый Prototype Javascript.  Русифицировал <a href="http://lecactus.ru">Lecactus</a>
Version: 0.7 rus
Author: Kjell Bublitz
Author URI: http://www.m3nt0r.de/blog/
*/

define("LIGHTBOX_EXTENSIONS",      'jpg|jpeg|png|gif');   	// checking for extension, divided by pipes (no leading or trailing pipe!!)
define("LIGHTBOX_DISABLE_WORD",    '##NOLIGHTBOX##');   		// disables the lightbox converter on the whole post/page

/*******************************************************************
*	DON'T EDIT BELOW THIS LINE UNLESS YOU KNOW WHAT YOU ARE DOING
*******************************************************************/

	// for version control and installation
	define('LIGHTBOX_VERSION', '0.7/2.03.3');

	// detect the plugin path
	$lightbox_path = get_settings('siteurl').'/wp-content/plugins/lightbox';

	// try to always get the values from the database
	$lightbox_speed = get_option(lightbox_speed);
	$lightbox_border = get_option(lightbox_border);
	$lightbox_opacity = get_option(lightbox_opacity);
	$lightbox_animate = get_option(lightbox_animate);
	$lightbox_version = get_option(lightbox_version);
	$lightbox_posts = get_option(lightbox_posts);
	$lightbox_excerpt = get_option(lightbox_excerpt);
	$lightbox_comments = get_option(lightbox_comments);

	// if the database value returns empty use defaults
	if($lightbox_version != LIGHTBOX_VERSION)
	{
		$lightbox_version = LIGHTBOX_VERSION;
		$lightbox_speed =  '7';
		$lightbox_border = '10';
		$lightbox_opacity = '0.8';
		$lightbox_animate = 'true';
		$lightbox_posts = 'true';
		$lightbox_excerpt = 'false';
		$lightbox_comments = 'false';
	}

	/**
	 * Creates the necessary HTML for the wp_head() action.
	 *
	 * @package Lightbox Plugin
	 */
     function lightbox_header()
     {
     	global $lightbox_path, $lightbox_speed, $lightbox_border,
     		$lightbox_opacity, $lightbox_animate, $lightbox_version;

		// prepare header and print
		$lightboxHead = "\n\t<!-- Lightbox Plugin {$lightbox_version} -->\n\t<link rel=\"stylesheet\" href=\"{$lightbox_path}/css/lightbox.css\" type=\"text/css\" media=\"screen\" />\n";
		$lightboxHead.= "\t<script type=\"text/javascript\"><!--\n\t\tvar fileLoadingImage = '{$lightbox_path}/images/loading.gif';\n\t\tvar fileBottomNavCloseImage = '{$lightbox_path}/images/closelabel.gif';\n\t\tvar resizeSpeed = {$lightbox_speed};\n\t\tvar borderSize = {$lightbox_border};\n\t\tvar animate = {$lightbox_animate};\n\t\tvar overlayOpacity = {$lightbox_opacity};\n\t//--></script>\n";
		$lightboxHead.= "\t<script type=\"text/javascript\" src=\"{$lightbox_path}/js/prototype.js\"></script>\n";
		$lightboxHead.= "\t<script type=\"text/javascript\" src=\"{$lightbox_path}/js/effects.js\"></script>\n";
		$lightboxHead.= "\t<script type=\"text/javascript\" src=\"{$lightbox_path}/js/lightbox.js\"></script>\n\t<!-- /Lightbox Plugin -->\n";

		print($lightboxHead);
     }

	/**
	 * Scans the whole content passed by the filter hook and
	 * looks for links, then for images, then for rel-tags, then
	 * for a optional title tag and finally adds the lightbox bit.
	 *
	 * @param string $content The content from the tag filter
	 * @return string Modified content, if any imagelinks where found
	 * @package Lightbox Plugin
	 */
	function lightbox_converter($content)
	{
		if(strpos($content, LIGHTBOX_DISABLE_WORD) === false)
		{
			// actually i tested that those support single and double quotes.
			// yes, i really suck at regex, but it works. feel free to submit patches :)
			$link_reg = "/<a\s*.*?href\s*=\s*['\"]([^\"'>]*).*?>(.*?)<\/a>/i";
			$title_reg = '#title\s*=\s*[\'|"]*([^("|\')\s>]*)#';
			$rel_reg = '#rel\s*=\s*[\'|"]*([^("|\')\s>]*)#';
			$image_reg = '#^(.*?\.('.LIGHTBOX_EXTENSIONS.')$)#is';

			if(preg_match_all($link_reg, $content, $links)) // find all links, if any
			{
				foreach($links[1] as $num => $link) // check all URLs
				{
					if(preg_match($image_reg, $link)) // if the URL leads to an image
					{
						$link_html = $links[0][$num];

						// remove nofollows, to avoid false positives in image links (comments, actually)
						$link_html = str_replace('rel="nofollow"', '', $link_html);
						$link_html = str_replace("rel='nofollow'", '', $link_html);

						// no rel-tag yet?
						if(!preg_match($rel_reg, $link_html))
						{
							// any title-tag ?
							if(preg_match($title_reg, $link_html, $title))
							{
								// series-title tag maybe ?
								if(preg_match('/{(.*)}/', $title[1], $series))
								{
									$new_link_html = str_replace('<a ', '<a rel="lightbox['.$series[1].']" ', $link_html);
									$new_link_html = str_replace($series[0], '', $new_link_html);
								}
								else // single lightbox
								{
									$new_link_html = str_replace('<a ', '<a rel="lightbox" ', $link_html);
								}
							}
							else // single lightbox
							{
								$new_link_html = str_replace('<a ', '<a rel="lightbox" ', $link_html);
							}

							// replace old <a href..> with new one
							$content = str_replace($link_html, $new_link_html, $content);
						}
					}
				} // loop
			}
		}
		return $content;
	}

	/**
	 * Creates the Option Page
	 *
	 * @package Lightbox Plugin
	 * @see lightbox_options()
	 */
	function lightbox_pages() {
	    add_options_page('Настройки Lightbox', 'Настройки Lightbox', 5, 'lightboxoptions', 'lightbox_options');
	}

	/**
	 * Outputs the HTML for the options page
	 *
	 * @package Lightbox Plugin
	 * @see lightbox_pages()
	 */
	function lightbox_options()
	{
     	global $lightbox_path, $lightbox_speed, $lightbox_border,
     		$lightbox_opacity, $lightbox_animate, $lightbox_version,
     		$lightbox_posts, $lightbox_excerpt, $lightbox_comments;

     	// if settings are updated
		if(isset($_POST['update_lightbox']))
		{
			if(is_numeric($_POST['lightbox_speed'])) {
				update_option('lightbox_speed', $_POST['lightbox_speed']);
				$lightbox_speed = $_POST['lightbox_speed'];
			}
			if(is_numeric($_POST['lightbox_border'])) {
				update_option('lightbox_border', $_POST['lightbox_border']);
				$lightbox_border = $_POST['lightbox_border'];
			}
			if(is_float($_POST['lightbox_opacity'])) {
				update_option('lightbox_opacity', $_POST['lightbox_opacity']);
				$lightbox_opacity = $_POST['lightbox_opacity'];
			}
			if($_POST['lightbox_animate'] == 'true' || $_POST['lightbox_animate'] == 'false') {
				update_option('lightbox_animate', $_POST['lightbox_animate']);
				$lightbox_animate = $_POST['lightbox_animate'];
			}
			if($_POST['lightbox_posts'] == 'true' || $_POST['lightbox_posts'] == 'false') {
				update_option('lightbox_posts', $_POST['lightbox_posts']);
				$lightbox_posts = $_POST['lightbox_posts'];
			}
			if($_POST['lightbox_excerpt'] == 'true' || $_POST['lightbox_excerpt'] == 'false') {
				update_option('lightbox_excerpt', $_POST['lightbox_excerpt']);
				$lightbox_excerpt = $_POST['lightbox_excerpt'];
			}
			if($_POST['lightbox_comments'] == 'true' || $_POST['lightbox_comments'] == 'false') {
				update_option('lightbox_comments', $_POST['lightbox_comments']);
				$lightbox_comments = $_POST['lightbox_comments'];
			}
		}

		// if the user clicks the uninstall button, clean all options and show good-bye message
		if(isset($_POST['uninstall_lightbox']))
		{
			delete_option(lightbox_speed);
			delete_option(lightbox_border);
			delete_option(lightbox_opacity);
			delete_option(lightbox_animate);
			delete_option(lightbox_version);
			delete_option(lightbox_posts);
			delete_option(lightbox_excerpt);
			delete_option(lightbox_comments);
			echo '<div class="wrap"><h2>До свидания!</h2><p>Все настройки lightbox были удалены и вы сейчас можете пройти в <a href="plugins.php">меню плагинов</a> и деактивировать его.</p><h3>Спасибо за использование Lightbox '.$lightbox_version.'!</h3><p style="text-align:right"><small>если вы сделали это случайно, <a href="options-general.php?page=lightboxoptions">нажмите сюда</a> чтобы переустановить</small></p></div>';

		}
		else // show the menu
		{

			// if the lightbox_version is empty or unequal,
			// write the defaults to the database
			if($lightbox_version != LIGHTBOX_VERSION)
			{
				update_option('lightbox_version', LIGHTBOX_VERSION);

				update_option('lightbox_speed', '7');
				update_option('lightbox_border', '10');
				update_option('lightbox_opacity', '0.8');
				update_option('lightbox_animate', 'true');

				update_option('lightbox_posts', 'true');
				update_option('lightbox_excerpt', 'false');
				update_option('lightbox_comments', 'false');
			}

			echo '<div class="wrap"><h2>Настройки Lightbox</h2><small style="display:block;text-align:right">Версия: '.$lightbox_version.'</small><form method="post" action="options-general.php?page=lightboxoptions">';
			echo '<input type="hidden" name="update_lightbox" value="true" />';

			echo '<table class="optiontable">';

			echo '<tr valign="top">';
			echo '<th scope="row">Анимация изменения размеров:</th>';
			echo '<td><select name="lightbox_animate" /><option value="true" '.($lightbox_animate?'selected':'').'>Анимировать изменение размеров</option><option value="false" '.(!$lightbox_animate?'selected':'').'>Не анимировать</option></select><br/>Управляет анимацией изменения размера поля вокруг картинки</td>';
			echo '</tr>';

			echo '<tr valign="top">';
			echo '<th scope="row">Скорость анимации:</th>';
			echo '<td><input name="lightbox_speed" type="text" id="blogname" value="'.$lightbox_speed.'" size="40" /><br/>1=медленно и 10=быстро, 7 по умолчанию</td>';
			echo '</tr>';

			echo '<tr valign="top">';
			echo '<th scope="row">Непрозрачность фона:</th>';
			echo '<td><input name="lightbox_opacity" type="text" id="blogname" value="'.$lightbox_opacity.'" size="40" /><br/>Управляет прозрачностью тени оверлея</td>';
			echo '</tr>';


			echo '<tr valign="top">';
			echo '<th scope="row">Размер границы:</th>';
			echo '<td><input name="lightbox_border" type="text" id="blogname" value="'.$lightbox_border.'" size="40" /><br/>Если Вы регулируете PADDING в CSS, вам нужно обновить его</td>';
			echo '</tr>';


			echo '</table>';
			echo '<p class="submit"><input type="submit" name="Submit" value="Обновить настройки &raquo;" /></p>';

			echo '<h2>Фильтр Lightbox\'а</h2>';
			echo '<table class="optiontable">';

			echo '<tr valign="top">';
			echo '<th scope="row">Фильтровать изображения в записях:</th>';
			echo '<td><select name="lightbox_posts" /><option value="true" '.($lightbox_posts=="true"?'selected':'').'>Да</option><option value="false" '.($lightbox_posts=="false"?'selected':'').'>Нет</option></select></td>';
			echo '</tr>';

			echo '<tr valign="top">';
			echo '<th scope="row">Фильтровать изображения в выдержках:</th>';
			echo '<td><select name="lightbox_excerpt" /><option value="true" '.($lightbox_excerpt=="true"?'selected':'').'>Да</option><option value="false" '.($lightbox_excerpt=="false"?'selected':'').'>Нет</option></select></td>';
			echo '</tr>';

			echo '<tr valign="top">';
			echo '<th scope="row">Фильтровать изображения в комментариях:</th>';
			echo '<td><select name="lightbox_comments" /><option value="true" '.($lightbox_comments=="true"?'selected':'').'>Да</option><option value="false" '.($lightbox_comments=="false"?'selected':'').'>Нет</option></select></td>';
			echo '</tr>';

			echo '</table>';
			echo '<p class="submit"><input type="submit" name="Submit" value="Обновить настройки &raquo;" /></p>';

			echo '</form>';


			echo '<h2>Деинсталляция</h2><form method="post" action="options-general.php?page=lightboxoptions">';
			echo '<input type="hidden" name="uninstall_lightbox" value="true" />';
			echo '<p class="submit"><input type="submit" name="Submit" value="Очистить настройки &raquo;" /></p>';
			echo '</form>';


			echo '<p>Предполагается что все файлы плагина расположены тут:<br />'.$lightbox_path.'/</p></div>';

		}
	}


/*******************************************************************
*	LINK THE FUNCTIONS TO THE FILTERS AND ACTIONS
*******************************************************************/

// add the options page to admin menu
	add_action('admin_menu', 'lightbox_pages');

// add lightbox header to theme
	add_action('wp_head', 'lightbox_header');

// add the content filter
	if($lightbox_posts == 'true')
	{
		add_filter('the_content', 'lightbox_converter', 5);
	}

	if($lightbox_excerpt == 'true')
	{
		add_filter('the_excerpt', 'lightbox_converter', 5);
	}

	if($lightbox_comments == 'true')
	{
		add_filter('comment_text', 'lightbox_converter', 50);
	}
?>